summaryrefslogtreecommitdiffstats
path: root/tools
diff options
context:
space:
mode:
authorKatja Marttila <katja.marttila@qt.io>2017-06-22 14:27:58 +0300
committerKatja Marttila <katja.marttila@qt.io>2017-06-22 11:47:44 +0000
commitd7ada4e0d84c48ff53de9c65d101b957b68236e8 (patch)
treed78eb1f1dfef812eb12e7590f8c805947c423195 /tools
parenta9544c7b6e7d5ff376d973c685f6da7eec9e0411 (diff)
Fix install type if --online-only passed to binarycreator
Binarycreator assumed that install type is offline if no repositories was set although --online-only was set. However, repositories might be set later, for example in producetkeycheck::init(). Change-Id: Idd6d0e3304974773baefe3773be7e2948704575c Reviewed-by: Iikka Eklund <iikka.eklund@qt.io>
Diffstat (limited to 'tools')
-rw-r--r--tools/binarycreator/binarycreator.cpp7
1 files changed, 5 insertions, 2 deletions
diff --git a/tools/binarycreator/binarycreator.cpp b/tools/binarycreator/binarycreator.cpp
index e74f8a18c..593110c8f 100644
--- a/tools/binarycreator/binarycreator.cpp
+++ b/tools/binarycreator/binarycreator.cpp
@@ -771,8 +771,11 @@ int main(int argc, char **argv)
{
QSettings confInternal(tmpMetaDir + QLatin1String("/config/config-internal.ini")
, QSettings::IniFormat);
- // assume offline installer if there are no repositories
- offlineOnly |= settings.repositories().isEmpty();
+ // assume offline installer if there are no repositories and no
+ //--online-only not set
+ offlineOnly = offlineOnly | settings.repositories().isEmpty();
+ if (onlineOnly)
+ offlineOnly = !onlineOnly;
confInternal.setValue(QLatin1String("offlineOnly"), offlineOnly);
}